Docker — Glances 2.8.3 documentation

# Docker

If you use `Docker`, Glances can help you to monitor your containers. Glances uses the Docker API through the docker-py library.

It is possible to define limits and actions from the configuration file under the `[docker]` section:

    [docker]
    # Global containers' thresholds for CPU and MEM (in %)
    cpu_careful=50
    cpu_warning=70
    cpu_critical=90
    mem_careful=20
    mem_warning=50
    mem_critical=70
    # Per container thresholds
    containername_cpu_careful=10
    containername_cpu_warning=20
    containername_cpu_critical=30
    containername_cpu_critical_action=echo {{Image}} {{Id}} {{cpu}} > /tmp/container_{{name}}.alert

You can use all the variables ({{foo}}) available in the Docker plugin.